@@ -1,4 +1,4 @@
-# $Id: Directory.pm 46967 2017-09-13 13:31:10Z anton $
+# $Id: Directory.pm 47260 2018-01-04 11:36:52Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -162,6 +162,7 @@ field 'ldapbase';
 field debug => 0;
 field usePagedResults => 0;
 field 'ssl' => 1;
+field 'tls' => 1;
 
 sub ldapError {
 	#callback heeft geen $self
@@ -186,32 +187,53 @@ sub ldap_connection {
 		my $ldapbase = $cfhash->{'ldapbase'} || $self->{ldapbase};
 		$self->ldapbase($ldapbase);
 
+		my $tls = $self->tls || 'off';
 		my $ssl = $self->ssl || 'on';
+
+		die "Inconsistent config: please choose ssl OR tls"
+			if ($tls eq 'on' && $ssl eq 'on');
+		
 		my $state;
 		my $debug = $self->debug;
 		warn "debug: $debug" if $debug;
-		warn "Connecting to ldapserver: $server"; # if $self->debug;
-		$ldap = new Net::LDAP($server,
-							  # onerror is o.a. NODIG om te reageren op foutieve authenticatie         
-							  # nadeel is gvd dat je niet meer kunt zien waar je error vandaan komt :(
-							  onerror => \&ldapError,
-							  timeout => 10,
-							  verify => 'require',
-							  raw => qr/(?i:^jpegPhoto|;binary)/,
-							  capath => $capath);
+		warn "Connecting to ldapserver: $server" if $self->debug;
+
+	  # onerror is o.a. NODIG om te reageren op foutieve authenticatie         
+	  # nadeel is gvd dat je niet meer kunt zien waar je error vandaan komt :(
+
+		if ($ssl eq 'on' ) {
+			$ldap = Net::LDAPS->new(
+					$server,
+					onerror => \&ldapError,
+					timeout => 10,
+					verify => 'require',
+					capath => $capath,
+				);
+	
+		} else {		
+
+		 	$ldap = new Net::LDAP(
+					$server,
+					onerror => \&ldapError,
+					timeout => 10,
+					verify => 'require',
+					raw => qr/(?i:^jpegPhoto|;binary)/,
+					capath => $capath);
+		}
 		$state = $@;
-		die "Error connecting to $server: $state" unless $ldap;
 		
-		unless ($ssl eq 'off') {
+		if ($tls eq 'on') {
 			$ldap->start_tls(verify => 'require', capath => $capath)
 				unless $ldap->cipher;
 		}
 
+		die "Error connecting to $server: $state" unless $ldap;
+		warn "Succesful ldap connection with: $server: $ldap";
 		$self->ldap($ldap);
 	}
 	my $bindAccountFilter = $self->bindAccountFilter;
 	my $bindAccount = $self->bindAccount;
-
+	
 	if ($bindAccountFilter || $bindAccount) {
 		unless ($bindAccount) {
 			warn "Using filter: \"$bindAccountFilter\" to find bindAccount" if $self->debug;
@@ -232,7 +254,6 @@ sub ldap_connection {
 		$ldap->bind($bindAccount, password => $self->bindPassword);
 		warn "Bind successful for: $bindAccount" if $self->debug; 
 
-
 	} else {
 		$ldap->bind;
 		warn "Anonymous bind successful" if $self->debug;
